@@ -21,7 +21,7 @@ from .main import http_request
 from . import errors
 from . import utils
 
-__version__ = "1.3.0"
+__version__ = "1.3.14"
 
 __all__ = ["Agent", "environments", "errors", "evaluate", "http_request",
            "make", "register", "utils", "__version__",
@@ -40,4 +40,4 @@ for name in listdir(utils.envs_path):
             "specification": getattr(env, "specification"),
         })
     except Exception as e:
-        print("Failed: %s: %s" % (name, e))
+        print("Loading environment %s failed: %s" % (name, e))
