@@ -1,4 +1,6 @@
 from kaggle_environments import make, evaluate
+from kaggle_environments.envs.football import helpers
+from helpers import Action
 from kaggle_environments.errors import DeadlineExceeded
 import copy
 import os
@@ -28,6 +30,19 @@ def clear_players_raw(state):
   return state
 
 
+@helpers.human_readable_agent
+def human_readable_agent(obs):
+    if Action.Sprint not in obs['sticky_actions']:
+        return Action.Sprint
+    controlled_player_pos = obs['left_team'][obs['active']]
+    if obs['ball_owned_player'] == obs['active'] and obs['ball_owned_team'] == 0:
+        if controlled_player_pos[0] > 0.5:
+            return Action.Shot
+        return Action.Right
+    else:
+        return Action.Slide
+
+
 def test_single_agent():
     before_each(configuration={"team_1": 1, "team_2": 0, "scenario_name": "11_vs_11_stochastic"})
     x = env.reset()
@@ -301,3 +316,18 @@ def test_render():
     assert output[0]['status'] == "DONE"
     assert output[1]['status'] == "DONE"
     assert os.path.isfile(video_file)
+
+
+def test_human_readable_agent():
+    before_each(configuration={"team_1": 1, "team_2": 1, "scenario_name": "tests.penalty"})
+    action = [0]
+    for _ in range(10):
+      obs = env.step([action, [0]])
+      action  = human_readable_agent(obs[0]['observation'])
+
+
+def test_score():
+    before_each(configuration={"team_1": 1, "team_2": 1, "scenario_name": "tests.goal_test", "save_video": True, "episode_number": 0})
+    res = env.run(["run_right", "run_right"])
+    assert res[-1][0]['reward'] == -1
+    assert res[-1][1]['reward'] == 1
