@@ -15,9 +15,9 @@
 import copy
 import json
 import math
-from os import path
-from random import choice, randint, sample, seed
 import numpy as np
+from os import path
+from random import choice, randint, randrange, sample, seed
 from .helpers import board_agent, Board, ShipAction, ShipyardAction
 from kaggle_environments import utils
 
@@ -87,9 +87,12 @@ def populate_board(state, env):
     uid_counter = 0
 
     # Set seed for random number generators
-    if hasattr(config, "randomSeed"):
-        np.random.seed(config.randomSeed)
-        seed(config.randomSeed)
+    if not hasattr(config, "randomSeed"):
+        max_int_32 = (1 << 31) - 1
+        config.randomSeed = randrange(max_int_32)
+
+    np.random.seed(config.randomSeed)
+    seed(config.randomSeed)
 
     # This is a consistent way to generate unique strings to form ship and shipyard ids
     def create_uid():
